##  Reverting View Colors
To revert a view and return to the default fact sheet colors:
  1. Choose Select a view at the top of the diagram.
  2. In the view menu for your fact sheet type, select Fact sheet colors.


![Dropdown menu showing Fact sheet colors and other view options for diagram categories.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioef08bb2f112c4294875780f508451464_LowRes.png)
Reverting View Colors in a Diagram
**Note**
When diagram data is loading or updating, the Select a view dropdown is temporarily unavailable. All other diagram functions work as expected.
